@@ -1,6 +1,6 @@
 #include <QtGui/QApplication>
 
-#include "ApplicationController.h"
+#include <rx/columbus/ColumbusController.h>
 
 #include "ui/MainWindow.h"
 
@@ -12,11 +12,13 @@ int main(int argc, char *argv[])
     QApplication::setApplicationVersion("0.8.1");
 
     QApplication            application (argc, argv);
-    ApplicationController   controller;
+    ColumbusController   controller;
 
     MainWindow              window;
     window.initialize(&controller);
 
+    controller.initialize();
+
 #if defined(Q_WS_MAEMO_5)
     window.showFullScreen();
 #else
