@@ -1,12 +1,11 @@
 #ifndef COLUMBUSDIALOGLOGGING_H
 #define COLUMBUSDIALOGLOGGING_H
 
-#include "widgets/Maemo5Dialog.h"
-#include "data/FileDataLoggerConfig.h"
+#include "widgets/ColumbusDialog.h"
 
 class ColumbusDialogLoggingPrivate;
 
-class ColumbusDialogLogging : public Maemo5Dialog
+class ColumbusDialogLogging : public ColumbusDialog
 {
     Q_OBJECT
 
@@ -15,7 +14,7 @@ public:
             ~ColumbusDialogLogging();
 
 public slots:
-    void setController(ApplicationController *controller);
+    void setController(ColumbusController *controller);
 
 protected slots:
     void setupUi();
