@@ -1,11 +1,11 @@
 #ifndef COLUMBUSDIALOGOPTIONS_H
 #define COLUMBUSDIALOGOPTIONS_H
 
-#include "widgets/Maemo5Dialog.h"
+#include "widgets/ColumbusDialog.h"
 
 class ColumbusDialogOptionsPrivate;
 
-class ColumbusDialogOptions : public Maemo5Dialog
+class ColumbusDialogOptions : public ColumbusDialog
 {
     Q_OBJECT
 
@@ -14,7 +14,7 @@ public:
                 ~ColumbusDialogOptions  ();
 
 public slots:
-    void         setController (ApplicationController *controller);
+    void         setController (ColumbusController *controller);
 
 private:
     void         addToggle          (const QString &key);
