@@ -1,21 +1,21 @@
 #ifndef COLUMBUSDIALOGTOOLS_H
 #define COLUMBUSDIALOGTOOLS_H
 
+#include "widgets/ColumbusDialog.h"
+
 #include <QMaemo5ValueButton>
 
-#include "widgets/Maemo5Dialog.h"
-
-class ColumbusDialogTools : public Maemo5Dialog
+class ColumbusDialogTools : public ColumbusDialog
 {
     Q_OBJECT
+
 public:
     explicit ColumbusDialogTools(QWidget *parent = 0);
 
-    void setController(ApplicationController *controller);
+    void setController(ColumbusController *controller);
 
 private:
     void                setupUi         ();
-    QMaemo5ValueButton* addPluginButton (const QString &label, const QString &value);
 };
 
 #endif // COLUMBUSDIALOGTOOLS_H
