@@ -6,13 +6,11 @@
 class ColumbusDialogWaypointsPrivate
 {
 public:
-    ApplicationController *controller;
-
     QScrollArea *scrollarea;
 };
 
 ColumbusDialogWaypoints::ColumbusDialogWaypoints(QWidget *parent)
-    : Maemo5Dialog(parent)
+    : ColumbusDialog(parent)
 {
     new QVBoxLayout(this);
     this->d = new ColumbusDialogWaypointsPrivate;
@@ -23,9 +21,9 @@ ColumbusDialogWaypoints::~ColumbusDialogWaypoints()
     delete this->d;
 }
 
-void ColumbusDialogWaypoints::setController(ApplicationController *controller)
+void ColumbusDialogWaypoints::setController(ColumbusController *controller)
 {
-    d->controller = controller;
+    ColumbusDialog::setController(controller);
 
     if(this->layout()->isEmpty())
     {
