@@ -1,11 +1,11 @@
 #ifndef COLUMBUSDIALOGWAYPOINTS_H
 #define COLUMBUSDIALOGWAYPOINTS_H
 
-#include "widgets/Maemo5Dialog.h"
+#include "widgets/ColumbusDialog.h"
 
 class ColumbusDialogWaypointsPrivate;
 
-class ColumbusDialogWaypoints : public Maemo5Dialog
+class ColumbusDialogWaypoints : public ColumbusDialog
 {
     Q_OBJECT
 
@@ -13,7 +13,7 @@ public:
     explicit ColumbusDialogWaypoints(QWidget *parent = 0);
             ~ColumbusDialogWaypoints();
 
-    void setController(ApplicationController *controller);
+    void setController(ColumbusController *controller);
 
 protected slots:
     void setupUi();
