@@ -18,8 +18,8 @@ public:
 
     QString                  friendlyName       () const;
 
-    ApplicationController*   controller         () const;
-    void                     setController      (ApplicationController *controller);
+    ColumbusController*      controller         () const;
+    void                     setController      (ColumbusController *controller);
 
 private slots:
     void         onLandscape                ();
