@@ -7,10 +7,6 @@
 #include <QHBoxLayout>
 #include <QPropertyAnimation>
 
-#include "widgets/AbstractCompass.h"
-#include "widgets/LCDIndicator.h"
-#include "widgets/TrackView.h"
-
 class ColumbusTrackViewPrivate;
 
 class ColumbusTrackView : public ApplicationView
@@ -22,7 +18,7 @@ public:
             ~ColumbusTrackView  ();
 
     QString  friendlyName   () const;
-    void     setController  (ApplicationController *controller);
+    void     setController  (ColumbusController *controller);
 
 public slots:
     void     cycleSpeedIndicator    ();
