@@ -1,8 +1,9 @@
 #ifndef ACCURACYGRAPH_H
 #define ACCURACYGRAPH_H
 
+#include <rx/columbus/ColumbusModel.h>
+
 #include "AbstractChart.h"
-#include "data/TripModel.h"
 
 class AccuracyGraphPrivate;
 
@@ -14,7 +15,7 @@ public:
     explicit     AccuracyGraph  (QWidget *parent = 0);
                 ~AccuracyGraph  ();
 
-    void         setModel(TripModel *model);
+    void         setModel(ColumbusModel *model);
 
 protected:
     void         paintEvent     (QPaintEvent *event);
