@@ -2,7 +2,8 @@
 #define ALTITUDEPROFILEGRAPH_H
 
 #include "AbstractChart.h"
-#include "data/TripModel.h"
+
+#include <rx/columbus/ColumbusModel.h>
 
 class AltitudeProfileGraphPrivate;
 
@@ -13,10 +14,10 @@ class AltitudeProfileGraph : public AbstractChart
 public:
     explicit AltitudeProfileGraph(QWidget *parent = 0);
 
-    TripModel* tripModel() const;
+    ColumbusModel* model() const;
 
 public slots:
-    void setTripModel(TripModel *model);
+    void setColumbusModel(ColumbusModel *model);
 
 protected:
     void paintEvent(QPaintEvent *event);
