@@ -3,7 +3,7 @@
 
 #include <QWidget>
 
-#include "data/TripModel.h"
+#include <rx/columbus/ColumbusModel.h>
 
 class TrackViewPrivate;
 
@@ -11,7 +11,7 @@ class TrackView : public QWidget
 {
     Q_OBJECT
 
-    Q_PROPERTY(TripModel* model READ model WRITE setModel NOTIFY modelUpdated)
+    Q_PROPERTY(ColumbusModel* model READ model WRITE setModel NOTIFY modelUpdated)
     Q_PROPERTY(qreal zoom READ zoom WRITE setZoom NOTIFY zoomUpdated)
     Q_PROPERTY(qreal rotation READ rotation WRITE setRotation NOTIFY rotationUpdated)
     Q_PROPERTY(QPointF position READ position WRITE setPosition NOTIFY positionUpdated)
@@ -20,21 +20,21 @@ public:
     explicit TrackView(QWidget *parent = 0);
             ~TrackView();
 
-    TripModel* model();
+    ColumbusModel* model();
 
     qreal zoom() const;
     qreal rotation() const;
     QPointF position() const;
 
 signals:
-    void modelUpdated(TripModel *model);
+    void modelUpdated(ColumbusModel *model);
 
     void zoomUpdated(qreal zoom);
     void rotationUpdated(qreal rotation);
     void positionUpdated(QPointF position);
 
 public slots:
-    void setModel(TripModel *model);
+    void setModel(ColumbusModel *model);
 
     void setZoom(qreal zoom);
     void setRotation(double rotation);
